Description Usage Arguments Value
Subset the file to get summary statistics information
1 | rd_info(file_to_rd)
|
file_to_rd |
the summary statistics file |
a list contains beta, se, n;
or the expo.beta, expo.se, expo.n of exposure trait in exposure ascertainment data set
the out.beta, out.se, out.n of outcome trait in exposure ascertainment data set
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.